import asyncio
import aiohttp
from bs4 import BeautifulSoup
global loop
loop = asyncio.get_event_loop()
class TikTok():
	async def run(acc):
		global accsx
		global soup
		accsx = []
		if type(acc) == list:
			for accs in acc:
				async with aiohttp.ClientSession() as session:
					async with session.get('http://tiktok.com/@%s?lang=en' % accs) as response:
						html = await response.text()
						soup = BeautifulSoup(html,'lxml')
						accsx.append(soup)
			soup = None
			return(accsx)
		else:
			async with aiohttp.ClientSession() as session:
					async with session.get('http://tiktok.com/@%s?lang=en' % acc) as response:
						html = await response.text()
						soup = BeautifulSoup(html,'lxml')
						accsx = None
						return(soup)
	async def status():
		global accsx
		global soup
		res = []
		if soup == None:
			for soup in accsx:
				try:
					parse = soup.find('h2','share-desc mt10')
					stats = parse.text
					res.append(stats)
				except AttributeError as e:
					raise AttributeError('wrong id')
					
			soup = None
			return(res)
		else:
			try:
				parse = soup.find('h2','share-desc mt10')
				stats = parse.text
				return(stats)
			except AttributeError as e:
				raise AttributeError('wrong id')
				
	async def nickname():
		global accsx
		global soup
		res = []
		if soup == None:
			for soup in accsx:
				try:
					parse = soup.find('h1','share-sub-title')
					stats = parse.text
					res.append(stats)
				except AttributeError as e:
					raise AttributeError('wrong id')
					
			soup = None
			return(res)
		else:
			try:
				parse = soup.find('h1','share-sub-title')
				stats = parse.text
				return(stats)
			except AttributeError as e:
				raise AttributeError('wrong id')
				
	async def following():
		global accsx
		global soup
		res = []
		if soup == None:
			for soup in accsx:
				try:
					parse = soup.find('strong',title='Following')
					stats = parse.text
					res.append(stats)
				except AttributeError as e:
					raise AttributeError('wrong id')
					
			soup = None
			return(res)
		else:
			try:
				parse = soup.find('strong',title='Following')
				stats = parse.text
				return(stats)
			except AttributeError as e:
				raise AttributeError('wrong id')
				
	async def followers():
		global accsx
		global soup
		res = []
		if soup == None:
			for soup in accsx:
				try:
					parse = soup.find('strong',title='Followers')
					stats = parse.text
					res.append(stats)
				except AttributeError as e:
					raise AttributeError('wrong id')
					
			soup = None
			return(res)
		else:
			try:
				parse = soup.find('strong',title='Followers')
				stats = parse.text
				return(stats)
			except AttributeError as e:
				raise AttributeError('wrong id')
				
	async def likes():
		global accsx
		global soup
		res = []
		if soup == None:
			for soup in accsx:
				try:
					parse = soup.find('strong',title='Likes')
					stats = parse.text
					res.append(stats)
				except AttributeError as e:
					raise AttributeError('wrong id')
					
			soup = None
			return(res)
		else:
			try:
				parse = soup.find('strong',title='Likes')
				stats = parse.text
				return(stats)
			except AttributeError as e:
				raise AttributeError('wrong id')
				




# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['xh1scr']
setup_kwargs = {
    'name': 'xh1scr',
    'version': '1.0.3',
    'description': 'Asynchronous TikTok API Wrapper',
    'long_description': "## How to use\nIMPORT TikTok module\n```sh\nfrom xh1scr import TikTok\n```\nMake task in asynchronous func\n```sh\nasync def func():\n\tawait TikTok.run('xh1c2')\n\tstatus = await TikTok.status()\n\tlikes = await TikTok.likes()\n\tfollowers = await TikTok.followers()\n\tfollowing = await TikTok.following()\n\tnickname = await TikTok.nickname()\n\t]\n```\nbtw u can get list in run\n```sh\nfrom xh1scr import TikTok\nasync def func2():\n\tawait TikTok.run(['xh1c2','example','example2','and','more'])\n\tstatus = await TikTok.status()\n\tlikes = await TikTok.likes()\n\tfollowers = await TikTok.followers()\n\tfollowing = await TikTok.following()\n\tnickname = await TikTok.nickname()\n```\nRU\n\n## Как использовать\nДля работы с ним надо сделать task в асинхронной функции\n(я знаю есть такое же API но с подключенной авторизацией и поиском по id но плюс моего API это удобство использования)\n```sh\nfrom xh1scr import TikTok\nasync def func():\n\tawait TikTok.run('xh1c2') \n\tstatus = await TikTok.status() \n\tlikes = await TikTok.likes()\n\tfollowers = await TikTok.followers()\n\tfollowing = await TikTok.following()\n\tnickname = await TikTok.nickname()\n```\nТак же в run можно передать список значений\n```sh\nfrom xh1scr import TikTok\nasync def func2():\n\tawait TikTok.run(['xh1c2','example','example2','and','more'])\n\tstatus = await TikTok.status()\n\tlikes = await TikTok.likes()\n\tfollowers = await TikTok.followers()\n\tfollowing = await TikTok.following()\n\tnickname = await TikTok.nickname()\n```\n",
    'author': 'perfecto',
    'author_email': 'rektnpc@mail.ru',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'py_modules': modules,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
